<TS language="hi" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation>पता व नामपत्र बदलने के लिए दायीं कुंजी दबाइए </translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation>नया एड्रेस बनाएं</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>नया</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>चुने हुए एड्रेस को सिस्टम क्लिपबोर्ड पर कॉपी करें</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;कॉपी</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>&amp;बंद करें</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>चुने हुए एड्रेस को सूची से हटाएं</translation>
    </message>
    <message>
        <source>Enter address or label to search</source>
        <translation>ढूंढने के लिए एड्रेस या लेबल दर्ज करें</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>डेटा को मौजूदा टैब से एक फ़ाइल में निर्यात करें</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;निर्यात</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;मिटाए</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation>कॉइन भेजने के लिए एड्रेस चुनें</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation>कॉइन प्राप्त करने के लिए एड्रेस चुनें </translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation>&amp;चुनें</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation>एड्रेस भेजे जा रहें हैं</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation>एड्रेस प्राप्त किए जा रहें हैं</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation>भुगतान करने के लिए ये आपके बिटकॉइन एड्रेस हैं। कॉइन भेजने से पहले राशि और गंतव्य एड्रेस की हमेशा जाँच करें </translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation>&amp;एड्रेस कॉपी करें</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>कॉपी &amp;लेबल </translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;बदलाव करें</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation>एड्रेस की सूची निर्यात करें</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>कौमा सेपरेटेड फाइल (* .csv)</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>निर्यात विफल रहा</translation>
    </message>
    <message>
        <source>There was an error trying to save the address list to %1. Please try again.</source>
        <translation>एड्रेस की सूची को %1 में सहेजने का प्रयास करने में त्रुटि हुई। कृपया पुन: प्रयास करें।</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>लेबल</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>एड्रेस</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(लेबल नहीं है)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>पासफ़्रेज़ डायलॉग</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>पासफ्रेज़ दर्ज करें</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>नया पासफ्रेज़</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>नया पासफ्रेज़ दोबारा दर्ज करें </translation>
    </message>
    <message>
        <source>Show passphrase</source>
        <translation>पासफ्रेज़ उजागर करे</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>वॉलेट एन्क्रिप्ट करें</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>इस संचालान हेतु कृपया अपने वॉलेट के सुरक्षा संवाद को दर्ज करें</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>बटुए को अनलॉक करें</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to decrypt the wallet.</source>
        <translation>आपके वॉलेट को गोपनीय बनाने हेतु आपके वॉलेट का सुरक्षा संवाद अनिवार्य है</translation>
    </message>
    <message>
        <source>Decrypt wallet</source>
        <translation>वॉलेट को डिक्रिप्ट करें</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>पासफ़्रेज़ बदलें</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>वॉलेट एन्क्रिप्शन की पुष्टि करें</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR BITCOINS&lt;/b&gt;!</source>
        <translation>चेतावनी: यदि आपने वॉलेट को एन्क्रिप्ट करने के बाद पदबंध खो दी तो &lt;b&gt;आप सारे बिटकॉइन खो देंगे &lt;/b&gt;!</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation>क्या आप सुनिश्चित हैं कि आप अपने वॉलेट को एन्क्रिप्ट करना चाहते हैं ?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>वॉलेट को एन्क्रिप्ट किया गया है</translation>
    </message>
    <message>
        <source>Enter the new passphrase for the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
        <translation>वॉलेट में नया सुरक्षा संवाद दर्ज करें | कृपया दस या उससे अधिक, या फिर आठ या उससे अधिक अव्यवस्थित अंको से ही अपना सुरक्षा संवाद बनाएं ।</translation>
    </message>
    <message>
        <source>Enter the old passphrase and new passphrase for the wallet.</source>
        <translation>वॉलेट में पुराना एवं नया सुरक्षा संवाद दर्ज करें ।</translation>
    </message>
    <message>
        <source>Remember that encrypting your wallet cannot fully protect your bitcoins from being stolen by malware infecting your computer.</source>
        <translation>याद रखें कि अपने बटुए (वॉलेट) एन्क्रिप्ट करना आपके कंप्यूटर को संक्रमित करने वाले मैलवेयर द्वारा आपके बिटकॉइन को चोरी होने से पूरी तरह से सुरक्षित नहीं कर सकता है।</translation>
    </message>
    <message>
        <source>Wallet to be encrypted</source>
        <translation>बटुए "वॉलेट" को एन्क्रिप्ट किया जाना है</translation>
    </message>
    <message>
        <source>Your wallet is about to be encrypted. </source>
        <translation>आपका बटुआ "वॉलेट" एन्क्रिप्टेड होने वाला है।</translation>
    </message>
    <message>
        <source>Your wallet is now encrypted. </source>
        <translation>आपका बटुआ "वॉलेट" एन्क्रिप्ट हो गया है।</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation>महत्वपूर्ण: किसी भी पिछले बैकअप को आपने अपनी वॉलेट फ़ाइल से बनाया था, उसे नए जनरेट किए गए एन्क्रिप्टेड वॉलेट फ़ाइल से बदल दिया जाना चाहिए। सुरक्षा कारणों से, अनएन्क्रिप्टेड वॉलेट फ़ाइल के पिछले बैकअप बेकार हो जाएंगे जैसे ही आप नए, एन्क्रिप्टेड वॉलेट का उपयोग करना शुरू करते हैं।</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>वॉलेट एन्क्रिप्शन विफल रहा</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation>आंतरिक त्रुटि के कारण वॉलेट एन्क्रिप्शन विफल रहा। आपका वॉलेट "बटुआ" एन्क्रिप्ट नहीं किया गया था।</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation>आपूर्ति किए गए पासफ़्रेज़ मेल नहीं खाते हैं।</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation>वॉलेट अनलॉक विफल रहा</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation>वॉलेट डिक्रिप्शन के लिए दर्ज किया गया पासफ़्रेज़ गलत था।</translation>
    </message>
    <message>
        <source>Wallet decryption failed</source>
        <translation>वॉलेट डिक्रिप्शन विफल</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation>वॉलेट पासफ़्रेज़ को सफलतापूर्वक बदल दिया गया था।</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation>चेतावनी: कैप्स लॉक कुंजी चालू है!</translation>
    </message>
</context>
<context>
    <name>BanTableModel</name>
    <message>
        <source>IP/Netmask</source>
        <translation>आईपी /नेटमास्क "Netmask"</translation>
    </message>
    <message>
        <source>Banned Until</source>
        <translation> तक बैन कर दिया</translation>
    </message>
</context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Sign &amp;message...</source>
        <translation>हस्ताक्षर और संदेश ...</translation>
    </message>
    <message>
        <source>Synchronizing with network...</source>
        <translation>नेटवर्क से समकालिकरण जारी है ...</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;विवरण</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>वॉलेट का सामानया विवरण दिखाए !</translation>
    </message>
    <message>
        <source>&amp;Transactions</source>
        <translation>&amp; लेन-देन
</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>देखिए पुराने लेन-देन के विवरण !</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>बाहर जायें</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>अप्लिकेशन से बाहर निकलना !</translation>
    </message>
    <message>
        <source>&amp;About %1</source>
        <translation>और %1 के बारे में</translation>
    </message>
    <message>
        <source>Show information about %1</source>
        <translation>%1 के बारे में जानकारी दिखाएं</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>के बारे में और क्यूटी "Qt"</translation>
    </message>
    <message>
        <source>Show information about Qt</source>
        <translation>क्यूटी "Qt" के बारे में जानकारी दिखाएँ</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;विकल्प</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>और वॉलेट को गोपित "एन्क्रिप्ट" करें</translation>
    </message>
    <message>
        <source>&amp;Backup Wallet...</source>
        <translation>&amp;बैकप वॉलेट</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>और पासफ़्रेज़ बदलें</translation>
    </message>
    <message>
        <source>Create Wallet...</source>
        <translation>वॉलेट बनाएं</translation>
    </message>
    <message>
        <source>Create a new wallet</source>
        <translation>नया वॉलेट बनाएं</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation>तिजोरी</translation>
    </message>
    <message>
        <source>Click to disable network activity.</source>
        <translation>नेटवर्क एक्टिविटी बंद करने के लिए क्लिक करें</translation>
    </message>
    <message>
        <source>Network activity disabled.</source>
        <translation>नेटवर्क एक्टिविटी बंद हो गई है.</translation>
    </message>
    <message>
        <source>Click to enable network activity again.</source>
        <translation>नेटवर्क एक्टिविटी दोबारा शुरू करने के लिए क्लिक करें.</translation>
    </message>
    <message>
        <source>Syncing Headers (%1%)...</source>
        <translation>हेडर्स सिंक हो रहे हैं (%1%)...</translation>
    </message>
    <message>
        <source>Reindexing blocks on disk...</source>
        <translation>डिस्क पर ब्लॉक्स री-इंडेक्सिंग हो रहे हैं...</translation>
    </message>
    <message>
        <source>Proxy is &lt;b&gt;enabled&lt;/b&gt;: %1</source>
        <translation>प्रॉक्सी &lt;b&gt; चालू है &lt;/b&gt; : %1</translation>
    </message>
    <message>
        <source>Send coins to a Bitcoin address</source>
        <translation>इस पते पर बिटकौइन भेजें</translation>
    </message>
    <message>
        <source>Backup wallet to another location</source>
        <translation>वॉलेट का दूसरी जगह पर बैकअप लें</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>पहचान शब्द/अक्षर जो वॉलेट एनक्रिपशन के लिए इस्तेमाल किया है उसे बदलिए!</translation>
    </message>
    <message>
        <source>&amp;Verify message...</source>
        <translation>&amp;मैसेज वैरीफ़ाई करें...</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;भेजें</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>&amp;प्राप्त करें</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>&amp;दिखाएं/छिपाएं</translation>
    </message>
    <message>
        <source>Show or hide the main Window</source>
        <translation>मुख्य विंडो को दिखाएं या छिपाएं</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;फाइल</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;सेट्टिंग्स</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;मदद</translation>
    </message>
    <message>
        <source>Tabs toolbar</source>
        <translation>टैबस टूलबार</translation>
    </message>
    <message>
        <source>%1 behind</source>
        <translation>%1 पीछे</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>भूल</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>चेतावनी</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>जानकारी</translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>नवीनतम</translation>
    </message>
    <message>
        <source>Open a wallet</source>
        <translation>बटुआ खोलें</translation>
    </message>
    <message>
        <source>Close Wallet...</source>
        <translation>बटुआ बंद करें...</translation>
    </message>
    <message>
        <source>Close wallet</source>
        <translation>बटुआ बंद करें</translation>
    </message>
    <message>
        <source>Close All Wallets...</source>
        <translation>सारे बटुएँ बंद करें...</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>भेजी ट्रांजक्शन</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>प्राप्त हुई ट्रांजक्शन</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;unlocked&lt;/b&gt;</source>
        <translation>वॉलेट एन्क्रिप्टेड है तथा अभी लॉक्ड नहीं है</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation>वॉलेट एन्क्रिप्टेड है तथा अभी लॉक्ड है</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Quantity:</source>
        <translation>मात्रा :</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>राशि :</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>राशि</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>taareek</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>पक्का</translation>
    </message>
    <message>
        <source>yes</source>
        <translation>हाँ</translation>
    </message>
    <message>
        <source>no</source>
        <translation>नहीं</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(कोई परचा नहीं )</translation>
    </message>
    </context>
<context>
    <name>CreateWalletActivity</name>
    </context>
<context>
    <name>CreateWalletDialog</name>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>पता एडिट करना</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>&amp;लेबल</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>&amp;पता</translation>
    </message>
    </context>
<context>
    <name>FreespaceChecker</name>
    </context>
<context>
    <name>HelpMessageDialog</name>
    <message>
        <source>version</source>
        <translation>संस्करण</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message>
        <source>Bitcoin</source>
        <translation>बीटकोइन</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>भूल</translation>
    </message>
    </context>
<context>
    <name>ModalOverlay</name>
    <message>
        <source>Form</source>
        <translation>फार्म</translation>
    </message>
    </context>
<context>
    <name>OpenURIDialog</name>
    </context>
<context>
    <name>OpenWalletActivity</name>
    </context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>विकल्प</translation>
    </message>
    <message>
        <source>W&amp;allet</source>
        <translation>वॉलेट</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;ओके</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;कैन्सल</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>भूल</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>फार्म</translation>
    </message>
    </context>
<context>
    <name>PSBTOperationsDialog</name>
    </context>
<context>
    <name>PaymentServer</name>
    </context>
<context>
    <name>PeerTableModel</name>
    </context>
<context>
    <name>QObject</name>
    <message>
        <source>Amount</source>
        <translation>राशि</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>लागू नही
</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>अज्ञात</translation>
    </message>
</context>
<context>
    <name>QRImageWidget</name>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>N/A</source>
        <translation>लागू नही
</translation>
    </message>
    <message>
        <source>&amp;Information</source>
        <translation>जानकारी</translation>
    </message>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>&amp;Amount:</source>
        <translation>राशि :</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>लेबल:</translation>
    </message>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Amount:</source>
        <translation>राशि :</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation>तिजोरी</translation>
    </message>
    <message>
        <source>Copy &amp;Address</source>
        <translation>&amp;पता कॉपी करे</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Date</source>
        <translation>taareek</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>परचा</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(कोई परचा नहीं )</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation>सिक्के भेजें|</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation>मात्रा :</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>राशि :</translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation>एक साथ कई प्राप्तकर्ताओं को भेजें</translation>
    </message>
    <message>
        <source>Balance:</source>
        <translation>बाकी रकम :</translation>
    </message>
    <message>
        <source>Confirm the send action</source>
        <translation>भेजने की पुष्टि करें</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(कोई परचा नहीं )</translation>
    </message>
</context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation>अमाउंट:</translation>
    </message>
    <message>
        <source>Pay &amp;To:</source>
        <translation>प्राप्तकर्ता:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>लेबल:</translation>
    </message>
    <message>
        <source>Alt+A</source>
        <translation>Alt-A</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Clipboard से एड्रेस paste करें</translation>
    </message>
    <message>
        <source>Alt+P</source>
        <translation>Alt-P</translation>
    </message>
    <message>
        <source>Pay To:</source>
        <translation>प्राप्तकर्ता:</translation>
    </message>
    </context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Alt+A</source>
        <translation>Alt-A</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Clipboard से एड्रेस paste करें</translation>
    </message>
    <message>
        <source>Alt+P</source>
        <translation>Alt-P</translation>
    </message>
    <message>
        <source>Signature</source>
        <translation>हस्ताक्षर</translation>
    </message>
    </context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    <message>
        <source>Date</source>
        <translation>दिनांक</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>स्रोत</translation>
    </message>
    <message>
        <source>Generated</source>
        <translation>उत्पन्न</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>अज्ञात</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>राशि</translation>
    </message>
    </context>
<context>
    <name>TransactionDescDialog</name>
    <message>
        <source>This pane shows a detailed description of the transaction</source>
        <translation>ये खिड़की आपको लेन-देन का विस्तृत विवरण देगी !</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>taareek</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>परचा</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(कोई परचा नहीं )</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>कोमा द्वारा अलग की गई फ़ाइल (* .csv)</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>पक्का</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>taareek</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>परचा</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>पता</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>निर्यात विफल रहा</translation>
    </message>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletController</name>
    <message>
        <source>Close wallet</source>
        <translation>बटुआ बंद करें</translation>
    </message>
    </context>
<context>
    <name>WalletFrame</name>
    <message>
        <source>Create a new wallet</source>
        <translation>नया वॉलेट बनाएं</translation>
    </message>
</context>
<context>
    <name>WalletModel</name>
    <message>
        <source>Send Coins</source>
        <translation>सिक्के भेजें|</translation>
    </message>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;निर्यात</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>डेटा को मौजूदा टैब से एक फ़ाइल में निर्यात करें</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>भूल</translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>This is a pre-release test build - use at your own risk - do not use for mining or merchant applications</source>
        <translation>यह एक पूर्व-रिलीज़ परीक्षण बिल्ड है - अपने जोखिम पर उपयोग करें - खनन या व्यापारी अनुप्रयोगों के लिए उपयोग न करें</translation>
    </message>
    <message>
        <source>Verifying blocks...</source>
        <translation>ब्लॉक्स जाँचे जा रहा है...</translation>
    </message>
    <message>
        <source>Loading block index...</source>
        <translation>ब्लॉक इंडेक्स आ रहा है...</translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>वॉलेट आ रहा है...</translation>
    </message>
    <message>
        <source>Cannot downgrade wallet</source>
        <translation>वॉलेट को डाउनग्रेड नहीं कर सकते</translation>
    </message>
    <message>
        <source>Rescanning...</source>
        <translation>रि-स्केनी-इंग...</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>लोड हो गया|</translation>
    </message>
</context>
</TS>